@@ -60,7 +60,7 @@ def run_python_activity(activity: Activity, configuration: Configuration,
                     sys.exc_info()[2])
 
 
-def validate_python_activity(activity: Activity):
+def validate_python_activity(activity: Activity):  # noqa: C901
     """
     Validate a Python activity.
 
@@ -76,7 +76,7 @@ def validate_python_activity(activity: Activity):
 
     This should be considered as a private function.
     """
-    name = activity["name"]
+    activity_name = activity["name"]
     provider = activity["provider"]
     mod_name = provider.get("module")
     if not mod_name:
@@ -91,7 +91,7 @@ def validate_python_activity(activity: Activity):
     except ImportError:
         raise InvalidActivity("could not find Python module '{mod}' "
                               "in activity '{name}'".format(
-                                  mod=mod_name, name=name))
+                                  mod=mod_name, name=activity_name))
 
     found_func = False
     arguments = provider.get("arguments", {})
@@ -142,5 +142,7 @@ def validate_python_activity(activity: Activity):
 
     if not found_func:
         raise InvalidActivity(
-            "'{mod}' does not expose '{func}' in activity '{name}'".format(
-                mod=mod_name, func=func, name=name))
+            "The python module '{mod}' does not expose a function called "
+            "'{func}' in {type} '{name}'".format(
+                mod=mod_name, func=func, type=activity['type'],
+                name=activity_name))
